package com.rthoni.camotion.ui.dialogs;

import android.app.Dialog;
import android.app.ProgressDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.support.v7.app.AlertDialog;

import com.luticate.auth.business.LuticatePermissionsBusiness;
import com.luticate.auth.business.LuticateUsersBusiness;
import com.luticate.auth.dbo.LuFullLoginDbo;
import com.luticate.auth.dbo.LuLoginDbo;
import com.luticate.auth.dbo.LuPermissionDbo;
import com.luticate.utils.business.LuPromise;
import com.luticate.utils.dbo.LuBoolDbo;
import com.luticate.utils.dbo.LuDataAccessConfigDbo;
import com.rthoni.camotion.R;
import com.rthoni.camotion.business.CommandsBusiness;
import com.rthoni.camotion.dbo.CommandDbo;
import com.rthoni.camotion.dbo.LocationDbo;

/**
 *
 * Created by robin on 11/28/15.
 */
public abstract class CommandExecDialog {

    public static void showDialog(final LuDataAccessConfigDbo config, final Context context, final CommandDbo command)
    {
        AlertDialog.Builder builder = new AlertDialog.Builder(context);
        builder.setMessage(context.getString(R.string.command_confirm, command.getName()))
                .setPositiveButton(android.R.string.yes, new DialogInterface.OnClickListener() {
                    @Override
                    public void onClick(DialogInterface dialog, int which) {
                        showLoadingDialog(config, context, command);
                    }
                })
                .setNegativeButton(android.R.string.no, null)
                .show();
    }

    protected static void showLoadingDialog(final LuDataAccessConfigDbo config, final Context context, final CommandDbo command)
    {
        final ProgressDialog dlg = new ProgressDialog(context);
        dlg.setIndeterminate(true);
        dlg.setTitle(R.string.loading);
        dlg.setMessage(context.getString(R.string.command_loading, command.getName()));
        dlg.setCancelable(false);
        dlg.show();
        CommandsBusiness.exec(config, command).then(new LuPromise.LuConsumer<LuBoolDbo>() {
            @Override
            public void execute(LuBoolDbo data) {
                dlg.hide();
                showEndDialog(context, context.getString(R.string.command_success, command.getName()));
            }
        }, new LuPromise.LuConsumer<LuPromise.LuPromiseError>() {
            @Override
            public void execute(LuPromise.LuPromiseError error) {
                dlg.hide();
                showEndDialog(context, context.getString(R.string.error, error.toString()));
            }
        });
    }

    protected static void showEndDialog(Context context, String text)
    {
        AlertDialog.Builder builder = new AlertDialog.Builder(context);
        builder.setMessage(text);
        builder.setPositiveButton(android.R.string.ok, null);
        builder.show();
    }
}
